#include "SCADOPT.hpp"
#include "OptimHeatEqnFDM.hpp"

const int DIM = 2;

int main(int argc, char *argv[]) {
    SCADOPT::Parameters paramsCl(argc, argv);
    ScaFES::GridGlobal<DIM> gg(paramsCl.params());

    const int nDfs = 2;
    const int nParamsToOptimize = DIM+1;

    std::vector<std::string> nameDatafield(nDfs);
    nameDatafield[0] = "Y";
    nameDatafield[1] = "U";
    std::vector<bool> isKnownDf(nDfs);
    isKnownDf[0] = false;
    isKnownDf[1] = true;
    std::vector<int> stencilWidth(nDfs);
    stencilWidth[0] = 1;
    stencilWidth[1] = 0;
    std::vector<int> nLayers(nDfs, 0);
    std::vector<bool> optimizeForDf(nDfs, false);
    std::vector<double> defaultValue(nDfs, 0.0);
    std::vector<ScaFES::WriteHowOften> writeToFile(nDfs);
    writeToFile[0] = ScaFES::WriteHowOften::AT_START;
    writeToFile[1] = ScaFES::WriteHowOften::NEVER;
    std::vector<bool> computeError(nDfs, true);
    computeError[0] = true;
    computeError[1] = false;

    std::vector<double> geomparamsInit(nParamsToOptimize, 1.1);
    geomparamsInit[0] = 4.5;
    std::vector<double> geomparamsSol(nParamsToOptimize, 1.0);
    geomparamsSol[0] = 4.0;

    OptimHeatEqnFDM<double, DIM> ppp(paramsCl, gg, false,
                     nameDatafield, stencilWidth,
                     isKnownDf, nLayers, optimizeForDf,
                     defaultValue, writeToFile,
                     computeError, geomparamsInit, geomparamsSol);
    ppp.minimizeTargetfct(std::string("lbfgsb"));
    return 0;
}
